# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-04-28 08:50
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_cms', '0003_auto_20170418_1515'),
    ]

    operations = [
        migrations.AddField(
            model_name='sliderelementtexten',
            name='name_file',
            field=models.CharField(blank=True, max_length=254, null=True, verbose_name='Name'),
        ),
        migrations.AddField(
            model_name='sliderelementtextes',
            name='name_file',
            field=models.CharField(blank=True, max_length=254, null=True, verbose_name='Name'),
        ),
        migrations.AddField(
            model_name='staticheaderelementtexten',
            name='name_file',
            field=models.CharField(blank=True, max_length=254, null=True, verbose_name='Name'),
        ),
        migrations.AddField(
            model_name='staticheaderelementtextes',
            name='name_file',
            field=models.CharField(blank=True, max_length=254, null=True, verbose_name='Name'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-02-27 10:00
from __future__ import unicode_literals

import codenerix.fields
import codenerix.lib.helpers
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Slider',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('identifier', models.CharField(blank=True, max_length=200, null=True, verbose_name='Identifier')),
                ('public', models.BooleanField(default=False, verbose_name='Public')),
                ('default', models.BooleanField(default=False, verbose_name='Default')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='SliderElement',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('order', models.IntegerField(verbose_name='Order')),
                ('show_title', models.BooleanField(default=False, verbose_name='Show tittle')),
                ('public', models.BooleanField(default=False, verbose_name='Public')),
                ('html_format', models.CharField(blank=True, choices=[('a', 'A'), ('b', 'B'), ('c', 'C')], max_length=2, null=True, verbose_name='HtmlFormat')),
                ('new_price', models.CharField(blank=True, max_length=200, null=True, verbose_name='New price')),
                ('old_price', models.CharField(blank=True, max_length=200, null=True, verbose_name='Old price')),
                ('discount', models.CharField(blank=True, max_length=200, null=True, verbose_name='Discount')),
                ('slider', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='sliderelements', to='codenerix_cms.Slider', verbose_name='Slider')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='SliderElementTextEN',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('image', codenerix.fields.ImageAngularField(blank=True, max_length=200, null=True, upload_to=codenerix.lib.helpers.upload_path, verbose_name='Image')),
                ('title', models.CharField(blank=True, max_length=200, null=True, verbose_name='Title')),
                ('description', models.TextField(blank=True, null=True, verbose_name='Description')),
                ('button', models.CharField(blank=True, max_length=200, null=True, verbose_name='Button')),
                ('url', models.CharField(max_length=500, verbose_name='URL')),
                ('slider_element', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='en', to='codenerix_cms.SliderElement')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='SliderElementTextES',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('image', codenerix.fields.ImageAngularField(blank=True, max_length=200, null=True, upload_to=codenerix.lib.helpers.upload_path, verbose_name='Image')),
                ('title', models.CharField(blank=True, max_length=200, null=True, verbose_name='Title')),
                ('description', models.TextField(blank=True, null=True, verbose_name='Description')),
                ('button', models.CharField(blank=True, max_length=200, null=True, verbose_name='Button')),
                ('url', models.CharField(max_length=500, verbose_name='URL')),
                ('slider_element', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='es', to='codenerix_cms.SliderElement')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Staticheader',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('identifier', models.CharField(blank=True, max_length=200, null=True, verbose_name='Identifier')),
                ('public', models.BooleanField(default=False, verbose_name='Public')),
                ('html_format', models.CharField(blank=True, choices=[('a', 'A'), ('b', 'B'), ('c', 'C')], max_length=2, null=True, verbose_name='HtmlFormat')),
                ('num_elements', models.IntegerField(verbose_name='Number of columns')),
                ('default', models.BooleanField(default=False, verbose_name='By default')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='StaticheaderElement',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('order', models.IntegerField(verbose_name='Order')),
                ('show_title', models.BooleanField(default=False, verbose_name='Show tittle')),
                ('public', models.BooleanField(default=False, verbose_name='Public')),
                ('frontheader', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='staticheaderelements', to='codenerix_cms.Staticheader', verbose_name='Static Header')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='StaticheaderElementTextEN',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('image', codenerix.fields.ImageAngularField(blank=True, max_length=200, null=True, upload_to=codenerix.lib.helpers.upload_path, verbose_name='Image')),
                ('title', models.CharField(blank=True, max_length=200, null=True, verbose_name='Title')),
                ('description', models.TextField(blank=True, null=True, verbose_name='Description')),
                ('button', models.CharField(blank=True, max_length=200, null=True, verbose_name='Button')),
                ('url', models.CharField(max_length=500, verbose_name='URL')),
                ('staticheader_element', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='en', to='codenerix_cms.StaticheaderElement')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='StaticheaderElementTextES',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('image', codenerix.fields.ImageAngularField(blank=True, max_length=200, null=True, upload_to=codenerix.lib.helpers.upload_path, verbose_name='Image')),
                ('title', models.CharField(blank=True, max_length=200, null=True, verbose_name='Title')),
                ('description', models.TextField(blank=True, null=True, verbose_name='Description')),
                ('button', models.CharField(blank=True, max_length=200, null=True, verbose_name='Button')),
                ('url', models.CharField(max_length=500, verbose_name='URL')),
                ('staticheader_element', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='es', to='codenerix_cms.StaticheaderElement')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='StaticPage',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('status', models.CharField(choices=[(b'D', 'Draft'), (b'R', 'Public'), (b'P', 'Pending')], default=b'D', max_length=150, verbose_name='Status')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='StaticPageTextEN',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('slug', models.CharField(max_length=200, unique=True, verbose_name='slug')),
                ('tiles', codenerix.fields.MultiBlockWysiwygField(blank=True, verbose_name='Tiles')),
                ('static_page', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='en', to='codenerix_cms.StaticPage')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='StaticPageTextES',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('slug', models.CharField(max_length=200, unique=True, verbose_name='slug')),
                ('tiles', codenerix.fields.MultiBlockWysiwygField(blank=True, verbose_name='Tiles')),
                ('static_page', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='es', to='codenerix_cms.StaticPage')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='TemplateStaticPage',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Created')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='Updated')),
                ('name', models.CharField(max_length=150, verbose_name='Name')),
                ('template', models.TextField(verbose_name='Template')),
                ('tile', models.TextField(verbose_name='Tile')),
            ],
            options={
                'default_permissions': ('add', 'change', 'delete', 'view', 'list'),
                'abstract': False,
            },
        ),
        migrations.AddField(
            model_name='staticpage',
            name='template',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='staticpages', to='codenerix_cms.TemplateStaticPage'),
        ),
    ]



# -*- coding: utf-8 -*-
#
# django-codenerix-cms
#
# Copyright 2017 Centrologic Computational Logistic Center S.L.
#
# Project URL : http://www.codenerix.com
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from django import template

from codenerix_cms.templatetags_tags import cdnx_slider, cdnx_staticheader


def f(x):
    return lambda identifier, lang, template='codenerix_cms/slider.html', *args, **kwargs: x(identifier, lang, template, *args, **kwargs)


def d(x):
    return lambda identifier, lang, template='codenerix_cms/staticheader.html', *args, **kwargs: x(identifier, lang, template, *args, **kwargs)


register = template.Library()

register.simple_tag(f(cdnx_slider), name="cdnx_slider")
register.simple_tag(d(cdnx_staticheader), name='cdnx_staticheader')



# -*- coding: utf-8 -*-
#
# django-codenerix-cms
#
# Copyright 2017 Centrologic Computational Logistic Center S.L.
#
# Project URL : http://www.codenerix.com
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from django.conf.urls import url

from codenerix_cms.views import \
    SliderList, SliderCreate, SliderCreateModal, SliderUpdate, SliderUpdateModal, SliderDelete, SliderDetail, \
    SliderElementSublist, SliderElementCreate, SliderElementCreateModal, SliderElementUpdate, SliderElementUpdateModal, SliderElementDelete, \
    StaticheaderList, StaticheaderCreate, StaticheaderCreateModal, StaticheaderUpdate, StaticheaderUpdateModal, StaticheaderDelete, StaticheaderDetails, \
    StaticheaderElementSubList, StaticheaderElementCreateModal, StaticheaderElementUpdateModal, StaticheaderElementDelete, \
    StaticPageList, StaticPageCreate, StaticPageCreateModal, StaticPageUpdate, StaticPageUpdateModal, StaticPageDelete, \
    StaticPageAuthorList, StaticPageAuthorCreate, StaticPageAuthorCreateModal, StaticPageAuthorUpdate, StaticPageAuthorUpdateModal, StaticPageAuthorDelete, \
    TemplateStaticPageList, TemplateStaticPageCreate, TemplateStaticPageCreateModal, TemplateStaticPagePageUpdate, TemplateStaticPageUpdateModal, TemplateStaticPageDelete, TemplateStaticPageForeign
# SliderElementDetailsModal, \
# StaticheaderElementDetailsModal, \
# SliderList, SliderCreate, SliderCreateModal, SliderUpdate, SliderUpdateModal, SliderDelete, SliderSublist, SliderDetail,


urlpatterns = [

    url(r'^sliders$', SliderList.as_view(), name='CDNX_cms_slider_list'),
    url(r'^sliders/add$', SliderCreate.as_view(), name='CDNX_cms_slider_add'),
    url(r'^sliders/addmodal$', SliderCreateModal.as_view(), name='CDNX_cms_slider_addmodal'),
    url(r'^sliders/(?P<pk>\w+)/edit$', SliderUpdate.as_view(), name='CDNX_cms_slider_edit'),
    url(r'^sliders/(?P<pk>\w+)/editmodal$', SliderUpdateModal.as_view(), name='CDNX_cms_slider_editmodal'),
    url(r'^sliders/(?P<pk>\w+)/delete$', SliderDelete.as_view(), name='CDNX_cms_slider_delete'),
    url(r'^sliders/(?P<pk>\w+)$', SliderDetail.as_view(), name='CDNX_cms_slider_detail'),
    
    url(r'^sliderelements/(?P<pk>\w+)/sublist$', SliderElementSublist.as_view(), name='CDNX_cms_slider_element_sublist'),
    url(r'^sliderelements/(?P<tpk>\w+)/sublist/addmodal$', SliderElementCreateModal.as_view(), name='CDNX_cms_slider_element_sublist_add'),
    # url(r'^sliderelements/(?P<tpk>\w+)/sublist/(?P<pk>\w+)/modal$', SliderElementDetailsModal.as_view(), name='slider_element_sublist_detail'),
    url(r'^sliderelements/(?P<tpk>\w+)/sublist/(?P<pk>\w+)/editmodal$', SliderElementUpdateModal.as_view(), name='CDNX_cms_slider_element_sublist_edit'),
    url(r'^sliderelements/(?P<tpk>\w+)/sublist/(?P<pk>\w+)/delete$', SliderElementDelete.as_view(), name='CDNX_cms_slider_element_sublist_delete'),
    
    
    url(r'^staticheaders$', StaticheaderList.as_view(), name='CDNX_cms_staticheader_list'),
    url(r'^staticheaders/add$', StaticheaderCreate.as_view(), name='CDNX_cms_staticheader_add'),
    url(r'^staticheaders/addmodal$', StaticheaderCreateModal.as_view(), name='CDNX_cms_staticheader_addmodal'),
    url(r'^staticheaders/(?P<pk>\w+)$', StaticheaderDetails.as_view(), name='CDNX_cms_staticheader_details'),
    url(r'^staticheaders/(?P<pk>\w+)/edit$', StaticheaderUpdate.as_view(), name='CDNX_cms_staticheader_edit'),
    url(r'^staticheaders/(?P<pk>\w+)/editmodal$', StaticheaderUpdateModal.as_view(), name='CDNX_cms_staticheader_editmodal'),
    url(r'^staticheaders/(?P<pk>\w+)/delete$', StaticheaderDelete.as_view(), name='CDNX_cms_staticheader_delete'),
    
    
    url(r'^staticheaderelements/(?P<pk>\w+)/sublist$', StaticheaderElementSubList.as_view(), name='CDNX_cms_staticheader_element_sublistlist'),
    url(r'^staticheaderelements/(?P<cpk>\w+)/sublist/addmodal$', StaticheaderElementCreateModal.as_view(), name='CDNX_cms_staticheader_element_sublistlist_add'),
    # url(r'^staticheaderelements/(?P<tpk>\w+)/sublist/(?P<pk>\w+)/modal$', StaticheaderElementDetailsModal.as_view(), name='frontheader_sublistlist_details'),
    url(r'^staticheaderelements/(?P<tpk>\w+)/sublist/(?P<pk>\w+)/editmodal$', StaticheaderElementUpdateModal.as_view(), name='CDNX_cms_frontheader_sublistlist_edit'),
    url(r'^staticheaderelements/(?P<tpk>\w+)/sublist/(?P<pk>\w+)/delete$', StaticheaderElementDelete.as_view(), name='CDNX_cms_frontheader_sublistlist_delete'),
    

    url(r'^staticpages$', StaticPageList.as_view(), name='CDNX_cms_staticpages_list'),
    url(r'^staticpages/add$', StaticPageCreate.as_view(), name='CDNX_cms_staticpages_add'),
    url(r'^staticpages/addmodal$', StaticPageCreateModal.as_view(), name='CDNX_cms_staticpages_addmodal'),
    url(r'^staticpages/(?P<pk>\w+)/edit$', StaticPageUpdate.as_view(), name='CDNX_cms_staticpages_edit'),
    url(r'^staticpages/(?P<pk>\w+)/editmodal$', StaticPageUpdateModal.as_view(), name='CDNX_cms_staticpages_editmodal'),
    url(r'^staticpages/(?P<pk>\w+)/delete$', StaticPageDelete.as_view(), name='CDNX_cms_staticpages_delete'),

    url(r'^staticpageauthors$', StaticPageAuthorList.as_view(), name='CDNX_cms_staticpageauthors_list'),
    url(r'^staticpageauthors/add$', StaticPageAuthorCreate.as_view(), name='CDNX_cms_staticpageauthors_add'),
    url(r'^staticpageauthors/addmodal$', StaticPageAuthorCreateModal.as_view(), name='CDNX_cms_staticpageauthors_addmodal'),
    url(r'^staticpageauthors/(?P<pk>\w+)/edit$', StaticPageAuthorUpdate.as_view(), name='CDNX_cms_staticpageauthors_edit'),
    url(r'^staticpageauthors/(?P<pk>\w+)/editmodal$', StaticPageAuthorUpdateModal.as_view(), name='CDNX_cms_staticpageauthors_editmodal'),
    url(r'^staticpageauthors/(?P<pk>\w+)/delete$', StaticPageAuthorDelete.as_view(), name='CDNX_cms_staticpageauthors_delete'),

    
    url(r'^templatestaticpages$', TemplateStaticPageList.as_view(), name='CDNX_cms_templatestaticpages_list'),
    url(r'^templatestaticpages/add$', TemplateStaticPageCreate.as_view(), name='CDNX_cms_templatestaticpages_add'),
    url(r'^templatestaticpages/addmodal$', TemplateStaticPageCreateModal.as_view(), name='templatestaticpages_addmodal'),
    url(r'^templatestaticpages/(?P<pk>\w+)/edit$', TemplateStaticPagePageUpdate.as_view(), name='templatestaticpages_edit'),
    url(r'^templatestaticpages/(?P<pk>\w+)/editmodal$', TemplateStaticPageUpdateModal.as_view(), name='templatestaticpages_editmodal'),
    url(r'^templatestaticpages/(?P<pk>\w+)/delete$', TemplateStaticPageDelete.as_view(), name='templatestaticpages_delete'),
    url(r'^templatestaticpages/foreign/(?P<search>[\w\W]+|\*)$', TemplateStaticPageForeign.as_view(), name='CDNX_cms_templatestaticpage_foreign'),
]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-04-18 15:15
from __future__ import unicode_literals

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_cms', '0002_auto_20170327_1021'),
    ]

    operations = [
        migrations.AlterField(
            model_name='staticheader',
            name='num_elements',
            field=models.IntegerField(validators=[django.core.validators.MaxValueValidator(4), django.core.validators.MinValueValidator(1)], verbose_name='Number of columns'),
        ),
    ]



# -*- coding: utf-8 -*-
#
# django-codenerix-cms
#
# Copyright 2017 Centrologic Computational Logistic Center S.L.
#
# Project URL : http://www.codenerix.com
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from django.contrib import admin
from django.conf import settings

from codenerix_cms.models import Slider, SliderElement, StaticheaderElement, Staticheader, MODELS, StaticPage, TemplateStaticPage


admin.site.register(Slider)
admin.site.register(SliderElement)
admin.site.register(Staticheader)
admin.site.register(StaticheaderElement)
admin.site.register(StaticPage)
admin.site.register(TemplateStaticPage)


for info in MODELS:
    model = info[1]
    for lang_code in settings.LANGUAGES_DATABASES:
        query = "from codenerix_cms.models import {}Text{}\n".format(model, lang_code)
        query += "admin.site.register({}Text{})\n".format(model, lang_code)
        exec(query)



# -*- coding: utf-8 -*-
#
# django-codenerix-cms
#
# Copyright 2017 Centrologic Computational Logistic Center S.L.
#
# Project URL : http://www.codenerix.com
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from django.db.models import F
from django.conf import settings
from django.core.exceptions import ObjectDoesNotExist
from django.shortcuts import render_to_response
from django.template import TemplateDoesNotExist
from django.template.loader import get_template
from django.utils.translation import ugettext as _
from django.utils.safestring import mark_safe

from codenerix_cms.models import Slider, Staticheader


def cdnx_slider(identifier, lang, template='codenerix_cms/slider.html', *args, **kwargs):
    slider = None
    slider_list = None
    try:
        slider = Slider.objects.get(
            identifier=identifier,
            public=True
        )
    except ObjectDoesNotExist:
        sliders = Slider.objects.filter(
            public=True,
            default=True
        )
        if sliders.count() > 0:
            slider = sliders.first()
        else:
            slider = None

    if slider is not None:
        slider_list = slider.sliderelements.filter(
            public=True
        ).values(
            'new_price',
            'old_price',
            'discount',
            'html_format',
            'show_title',
            "{}__title".format(lang),
            "{}__description".format(lang),
            "{}__button".format(lang),
            "{}__url".format(lang),
            "{}__image".format(lang),
        ).annotate(
            title=F("{}__title".format(lang)),
            description=F("{}__description".format(lang)),
            button=F("{}__button".format(lang)),
            url=F("{}__url".format(lang)),
            image=F("{}__image".format(lang)),
        ).order_by('order')

    obj = None

    try:
        obj = get_template(template)
    except TemplateDoesNotExist:
        if getattr(settings, 'DEBUG', False):
            return _('Template not found')
        else:
            obj = None

    if obj:
        if slider_list:
            context = {}
            context['slider_list'] = slider_list
            return mark_safe(render_to_response(template, context)._container[0])
        else:
            return ''
    elif getattr(settings, 'DEBUG', False):
        return _("Identifier don't found")
    else:
        return ''


_BOOTSTRAP_COLUMN_SIZES = {
    1: (12, ),
    2: (6, 6),
    3: (6, 3, 3),
    4: (3, 3, 3, 3),
}

_LEFT = 'left'
_RIGHT = 'right'

_BOOTSTRAP_COLUMN_POSITIONS = {
    1: ('', ),
    2: (_LEFT, _RIGHT),
    3: ('', '', ''),
    4: ('', '', '', ''),
}


def cdnx_staticheader(identifier, lang, template='codenerix_cms/staticheader.html', *args, **kwargs):
    staticheader = None
    staticheader_list = None
    try:
        staticheader = Staticheader.objects.get(
            identifier=identifier,
            public=True
        )
    except ObjectDoesNotExist:
        staticheaders = Staticheader.objects.filter(
            public=True,
            default=True
        )
        if staticheaders.count() > 0:
            staticheader = staticheaders.first()
        else:
            staticheader = None

    if staticheader is not None:
        staticheader_list = staticheader.staticheaderelements.filter(
            public=True
        ).values(
            'show_title',
            "{}__title".format(lang),
            "{}__description".format(lang),
            "{}__button".format(lang),
            "{}__url".format(lang),
            "{}__image".format(lang),
        ).annotate(
            title=F("{}__title".format(lang)),
            description=F("{}__description".format(lang)),
            button=F("{}__button".format(lang)),
            url=F("{}__url".format(lang)),
            image=F("{}__image".format(lang)),
        ).order_by('order')

        column_sizes = _BOOTSTRAP_COLUMN_SIZES.get(staticheader.num_elements, 1)
        column_positions = _BOOTSTRAP_COLUMN_POSITIONS.get(staticheader.num_elements, ('', '', '', ''))
        for element, column_size, column_position in zip(staticheader_list, column_sizes, column_positions):
            element['column_size'] = column_size
            element['column_position'] = column_position

    obj = None
    try:
        obj = get_template(template)
    except TemplateDoesNotExist:
        if getattr(settings, 'DEBUG', False):
            return _('Template not found')
        else:
            obj = None

    if obj:
        if staticheader_list:
            context = {}
            context['staticheader'] = {
                'column_count': staticheader.num_elements,
                'html_format': staticheader.html_format
            }

            context['staticheader_list'] = staticheader_list
            return mark_safe(render_to_response(template, context)._container[0])
        else:
            return ''
    elif getattr(settings, 'DEBUG', False):
        return _('Identifier dont found')
    else:
        return ''



# -*- coding: utf-8 -*-
#
# django-codenerix-cms
#
# Copyright 2017 Centrologic Computational Logistic Center S.L.
#
# Project URL : http://www.codenerix.com
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from django import forms
from django.forms import ValidationError
from django.utils.translation import ugettext_lazy as _
from django.conf import settings

from codenerix.forms import GenModelForm
from codenerix.widgets import WysiwygAngularInput
from codenerix_cms.models import Slider, SliderElement, StaticheaderElement, Staticheader, MODELS, StaticPage, TemplateStaticPage, extract_regex_cdnxtiler, StaticPageAuthor


class SliderForm(GenModelForm):
    class Meta:
        model = Slider
        exclude = []

    def __groups__(self):
        return [
            (
                _(u'Grupo'), 12,
                ['identifier', 6],
                ['public', 3],
                ['default', 3],
            )
        ]

    @staticmethod
    def __groups_details__():
        return [
            (
                _(u'Grupo'), 12,
                ['identifier', 6],
                ['public', 6],
                ['default', 6],
            )
        ]


class SliderElementForm(GenModelForm):
    class Meta:
        model = SliderElement
        exclude = ['slider']
    
    """
    def clean(self):
        active = self.cleaned_data['active']
        group = self.cleaned_data['group']
        if active:
            l = Slider.objects.filter(group=group, active=True)
            # ¿por que?
            if len(l) >= 6:
                raise forms.ValidationError("You only can have 6 elements active at the time.")
        self.cleaned_data['active'] = active
        self.cleaned_data['group'] = group
        return self.cleaned_data
    """
    
    def __groups__(self):
        return [(_(u'Slider'), 12,
            ['order', 6],
            ['public', 3],
            ['show_title', 3],
            ['html_format', 6],
            ['new_price', 6, None, None, None, None, None, ["ng-keypress=reset_discount()", "ng-blur=change_price()"]],
            ['old_price', 6, None, None, None, None, None, ["ng-keypress=reset_discount()", "ng-blur=change_price()"]],
            ['discount', 6, None, None, None, None, None, ["ng-keypress=reset_oldprice()", "ng-blur=change_discount()"]],
        )
        ]

    @staticmethod
    def __groups_details__():
        return [(_(u'Slider'), 12,
            ['slider', 6],
            ['order', 6],
            ['show_title', 6],
            ['public', 6],
            ['html_format', 6],
            ['new_price', 6],
            ['old_price', 6],
            ['discount', 6],)
        ]


# DynamicLanguageForm(model, "{}Text".format(model), None, "{}TextForm".format(model))

class StaticheaderForm(GenModelForm):
    class Meta:
        model = Staticheader
        exclude = []

    def __groups__(self):
        return [(_(u'Grupo'), 12,
            ['identifier', 6],
            ['public', 3],
            ['default', 3],
            ['html_format', 6],
            ['num_elements', 6],
        )
        ]

    @staticmethod
    def __groups_details__():
        return [(_(u'Grupo'), 12,
            ['identifier', 6],
            ['public', 6],
            ['default', 6],
            ['html_format', 6],
            ['num_elements', 6],
        )
        ]


class StaticheaderElementForm(GenModelForm):
    class Meta:
        model = StaticheaderElement
        exclude = ['frontheader']

    def __groups__(self):
        return [(_(u'Slider'), 12,
            ['order', 6],
            ['public', 3],
            ['show_title', 3],
        )
        ]
    
    @staticmethod
    def __groups_details__():
        return [(_('Details'), 12,
            ['order', 6],
            ['show_title', 6],
            ['public', 6],
        )
        ]


class TemplateStaticPageForm(GenModelForm):
    class Meta:
        model = TemplateStaticPage
        exclude = ['tile']

    def __groups__(self):
        g = [
            (_('Details'), 12,
                ['name', 6],
                ['template', 6],
             )
        ]
        return g

    @staticmethod
    def __groups_details__():
        g = [
            (_('Details'), 12,
                ['name', 6],
                ['template', 6],
             )
        ]
        return g

    def clean_template(self):
        template = self.cleaned_data['template']
        res = TemplateStaticPage.check_template(template)
        for r in res:
            if r['code_error'] > 0:
                raise ValidationError(r['error_msg'])

        return template


class StaticPageForm(GenModelForm):

    class Meta:
        model = StaticPage
        exclude = []
        autofill = {
            'StaticPageForm_template': ['select', 3, 'CDNX_cms_templatestaticpage_foreign'],
            # 'StaticPageForm_author': ['select', 3, StaticPageAuthor.foreignkey_external()['related']],
        }

    def __groups__(self):
        g = [
            (
                _('Details'), 12,
                ['author', 5],
                ['template', 5],
                ['status', 2],
            )
        ]
        return g
    
    @staticmethod
    def __groups_details__():
        g = [
            (
                _('Details'), 12,
                ['author', 5],
                ['template', 5],
                ['status', 2],
            )
        ]
        return g


class StaticPageAuthorForm(GenModelForm):

    class Meta:
        model = StaticPageAuthor
        exclude = []

#    def __groups__(self):
#        g = [(_('Details'), 12,
#            ['author', 5],
#            ['template', 5],
#            ['status', 2],
#        )
#        ]
#        return g
    
#    @staticmethod
#    def __groups_details__():
#        g = [(_('Details'),12,
#            ['author', 5],
#            ['template', 5],
#            ['status', 2],
#        )
#        ]
#        return g


query = ""
forms_dyn = []
for info in MODELS:
    field = info[0]
    model = info[1]
    for lang_code in settings.LANGUAGES_DATABASES:
        query = "from codenerix_cms.models import {}Text{}\n".format(model, lang_code)
        exec(query)
        query = """
class {model}TextForm{lang}(GenModelForm):\n
    class Meta:\n
        model={model}Text{lang}\n
        exclude = ['name_file', ]\n
        """
        if model not in ("StaticheaderElement", "SliderElement"):
            query += """widgets = {{\n
            'description': WysiwygAngularInput(),\n
        }}\n"""
        query += """
    def __groups__(self):\n
        return [(_('Details'),12,"""
        if model != 'StaticPage':
            if lang_code == settings.LANGUAGES_DATABASES[0]:
                query += """
                    ['title', 12, None, None, None, None, None, ["ng-blur=refresh_lang_field('title', '{model}TextForm', [{languages}])"]],
                    ['url', 12, None, None, None, None, None, ["ng-blur=refresh_lang_field('url', '{model}TextForm', [{languages}])"]],
                    ['button', 12, None, None, None, None, None, ["ng-blur=refresh_lang_field('button', '{model}TextForm', [{languages}])"]],
                    ['image', 12, None, None, None, None, None, ["ng-blur=refresh_lang_field('image', '{model}TextForm', [{languages}])"]],
                    ['description', 12, None, None, None, None, None, ["ng-blur=refresh_lang_field('description', '{model}TextForm', [{languages}])"]],
                )]\n"""
            else:
                query += """
                    ['title', 12],
                    ['url', 12],
                    ['button', 12],
                    ['image', 12],
                    ['description', 12],
                )]\n"""
        else:
            if lang_code == settings.LANGUAGES_DATABASES[0]:
                query += """
                    ['slug', 12, None, None, None, None, None, ["ng-blur=refresh_lang_field('slug', '{model}TextForm', [{languages}])"]],
                    ['tiles', 12, None, None, None, None, None, ["ng-blur=refresh_lang_field('tiles', '{model}TextForm', [{languages}])"]],
                )]\n"""
            else:
                query += """
                    ['slug', 12],
                    ['tiles', 12],
                )]\n"""

        exec(query.format(model=model, lang=lang_code, languages="'{}'".format("','".join(settings.LANGUAGES_DATABASES))))



# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2017-11-15 14:46
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_cms', '0006_auto_20171108_1628'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='slider',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='sliderelement',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='sliderelementtexten',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='sliderelementtextes',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='staticheader',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='staticheaderelement',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='staticheaderelementtexten',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='staticheaderelementtextes',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='staticpagetexten',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
        migrations.AlterModelOptions(
            name='staticpagetextes',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'list')},
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2017-11-23 09:19
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_cms', '0007_auto_20171115_1546'),
    ]

    operations = [
        migrations.AlterField(
            model_name='sliderelement',
            name='show_title',
            field=models.BooleanField(default=False, verbose_name='Show title'),
        ),
        migrations.AlterField(
            model_name='staticheaderelement',
            name='show_title',
            field=models.BooleanField(default=False, verbose_name='Show title'),
        ),
    ]



# -*- coding: utf-8 -*-
#
# django-codenerix-cms
#
# Copyright 2017 Centrologic Computational Logistic Center S.L.
#
# Project URL : http://www.codenerix.com
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import json

from django import template
from django.contrib.auth.decorators import login_required
from django.core.exceptions import ValidationError
from django.db import transaction
from django.db.models import Q
from django.forms.utils import ErrorList
from django.http import HttpResponse
from django.utils.decorators import method_decorator
from django.utils.translation import ugettext as _

from django.conf import settings
from codenerix.multiforms import MultiForm
from codenerix.views import GenList, GenCreate, GenCreateModal, GenUpdate, GenUpdateModal, GenDelete, GenDetail, GenForeignKey

from codenerix_cms.models import Slider, SliderElement, StaticheaderElement, Staticheader, StaticPage, StaticPageAuthor, TemplateStaticPage, MODELS
from codenerix_cms.forms import SliderForm, SliderElementForm, StaticheaderForm, StaticheaderElementForm, StaticPageForm, StaticPageAuthorForm, TemplateStaticPageForm

register = template.Library()

# ##################################
formsfull = {}
for info in MODELS:
    field = info[0]
    model = info[1]
    formsfull[model] = [(None, None, None)]
    for lang_code in settings.LANGUAGES_DATABASES:
        query = "from codenerix_cms.models import {}Text{}\n".format(model, lang_code.upper())
        query += "from codenerix_cms.forms import {}TextForm{}".format(model, lang_code.upper())
        exec(query)

        formsfull[model].append((eval("{}TextForm{}".format(model, lang_code.upper())), field, None))


# ##################################
# Slider group
class SliderList(GenList):
    model = Slider
    extra_context = {'menu': ['SliderGroup', 'slidergroup'], 'bread': [_('Slider Group'), _('slider group')]}
    # link_add = True
    # link_edit = True
    show_details = True


class SliderCreate(GenCreate):
    model = Slider
    show_details = True
    form_class = SliderForm


class SliderCreateModal(GenCreateModal, SliderCreate):
    pass


class SliderUpdate(GenUpdate):
    model = Slider
    show_details = True
    form_class = SliderForm


class SliderUpdateModal(GenUpdateModal, SliderUpdate):
    pass


class SliderDelete(GenDelete):
    model = Slider


class SliderDetail(GenDetail):
    model = Slider
    groups = SliderForm.__groups_details__()
    exclude_fields = []
    tabs = [
        {
            'id': 'sliders', 'name': _('Sliders'),
            'ws': 'CDNX_cms_slider_element_sublist',
            'rows': 'base'
        },
    ]


# ##################################
# Slider
class SliderElementSublist(GenList):
    model = SliderElement
    show_details = False

    def __limitQ__(self, info):
        limit = {}
        pk = info.kwargs.get('pk', None)
        limit['file_link'] = Q(slider__pk=pk)
        return limit


# class SliderElementCreate(MultiForm, GenCreate, ImageFileView):
class SliderElementCreate(MultiForm, GenCreate):
    model = SliderElement
    form_class = SliderElementForm
    forms = formsfull["SliderElement"]
    form_ngcontroller = "CDNXCMSFormSliderCtrl"

    def form_valid(self, form, forms):
        new_forms = []
        for f in forms:
            if type(f[0]) != self.form_class:
                name_form = str(type(forms[1][0])).split('.')[-1].replace("'", '').replace('>', '')
                field_image = "{}_image".format(name_form)
                if field_image in json.loads(self.request.body) and 'filename' in json.loads(self.request.body)[field_image]:
                    name_file = json.loads(self.request.body)[field_image]['filename']
                    self.request.name_file = name_file
                    f[0].instance.name_file = name_file
            new_forms.append(f)
        return super(SliderElementCreate, self).form_valid(form, new_forms)


class SliderElementCreateModal(GenCreateModal, SliderElementCreate):
    @method_decorator(login_required)
    def dispatch(self, *args, **kwargs):
        self.__slider_pk = kwargs.get('tpk', None)
        return super(SliderElementCreateModal, self).dispatch(*args, **kwargs)

    def form_valid(self, form, forms):
        if self.__slider_pk:
            slider = Slider.objects.get(pk=self.__slider_pk)
            self.request.slider = slider
            form.instance.slider = slider

        return super(SliderElementCreateModal, self).form_valid(form, forms)


class SliderElementUpdate(MultiForm, GenUpdate):
    model = SliderElement
    form_class = SliderElementForm
    forms = formsfull["SliderElement"]
    form_ngcontroller = "CDNXCMSFormSliderCtrl"

    def form_valid(self, form, forms):
        new_forms = []
        for f in forms:
            if type(f[0]) != self.form_class:
                name_form = str(type(forms[1][0])).split('.')[-1].replace("'", '').replace('>', '')
                field_image = "{}_image".format(name_form)
                if field_image in json.loads(self.request.body) and 'filename' in json.loads(self.request.body)[field_image]:
                    name_file = json.loads(self.request.body)[field_image]['filename']
                    self.request.name_file = name_file
                    f[0].instance.name_file = name_file
            new_forms.append(f)
        return super(SliderElementUpdate, self).form_valid(form, new_forms)


class SliderElementUpdateModal(GenUpdateModal, SliderElementUpdate):
    pass


class SliderElementDelete(GenDelete):
    model = SliderElement


"""
class SliderElementDetailsModal(GenDetailModal):
    model = SliderElement
    groups = SliderElementForm.__groups_details__()
    exclude_fields = []

"""


# ###########################################
# Staticheader
class StaticheaderList(GenList):
    model = Staticheader
    extra_context = {'menu': ['StaticheaderGroup', 'people'], 'bread': [_('StaticheaderGroup'), _('People')]}
    show_details = True
    default_ordering = ["-public"]


class StaticheaderCreate(GenCreate):
    model = Staticheader
    form_class = StaticheaderForm
    show_details = True


class StaticheaderCreateModal(GenCreateModal, StaticheaderCreate):
    pass


class StaticheaderUpdate(GenUpdate):
    model = Staticheader
    form_class = StaticheaderForm
    show_details = True


class StaticheaderUpdateModal(GenUpdateModal, StaticheaderUpdate):
    pass


class StaticheaderDelete(GenDelete):
    model = Staticheader


class StaticheaderDetails(GenDetail):
    model = Staticheader
    groups = StaticheaderForm.__groups_details__()

    tabs = [
        {
            'id': 'staticheader',
            'name': _('Elements'),
            'ws': 'CDNX_cms_staticheader_element_sublistlist',
            'wsbase': 'staticheader_list',
            'rows': 'base'
        },
    ]
    exclude_fields = ['columns_distribution']


# ###########################################
# StaticheaderElement

static_staticheader_formsfull = [(None, None, None)]
for lang_code in settings.LANGUAGES_DATABASES:
    static_staticheader_formsfull.append((eval("StaticheaderElementText{}".format(lang_code)), 'slider_element', None))


class StaticheaderElementSubList(GenList):
    model = StaticheaderElement
    extra_context = {'menu': ['StaticheaderElement', 'people'], 'bread': [_('StaticheaderElement'), _('People')]}
    show_details = False
    # json = False
    # template_model = "frontheader/frontheader_sublist.html"

    def __limitQ__(self, info):
        limit = {}
        pk = info.kwargs.get('pk', None)
        limit['file_link'] = Q(frontheader__pk=pk)
        return limit


class StaticheaderElementCreate(MultiForm, GenCreate):
    model = StaticheaderElement
    form_class = StaticheaderElementForm
    forms = formsfull["StaticheaderElement"]

    def form_valid(self, form, forms):
        new_forms = []
        for f in forms:
            if type(f[0]) != self.form_class:
                name_form = str(type(forms[1][0])).split('.')[-1].replace("'", '').replace('>', '')
                field_image = "{}_image".format(name_form)
                if field_image in json.loads(self.request.body) and 'filename' in json.loads(self.request.body)[field_image]:
                    name_file = json.loads(self.request.body)[field_image]['filename']
                    self.request.name_file = name_file
                    f[0].instance.name_file = name_file
            new_forms.append(f)

        try:
            return super(StaticheaderElementCreate, self).form_valid(form, new_forms)
        except ValidationError as e:
            errors = form._errors.setdefault("public", ErrorList())
            errors.append(e)
            return super(StaticheaderElementCreate, self).form_invalid(form, [tform[0] for tform in forms], 1, 0)


class StaticheaderElementCreateModal(GenCreateModal, StaticheaderElementCreate):
    @method_decorator(login_required)
    def dispatch(self, *args, **kwargs):
        self.__frontheader_pk = kwargs.get('cpk', None)
        return super(StaticheaderElementCreateModal, self).dispatch(*args, **kwargs)

    def form_valid(self, form, forms):
        if self.__frontheader_pk:
            frontheader = Staticheader.objects.get(pk=self.__frontheader_pk)
            self.request.frontheader = frontheader
            form.instance.frontheader = frontheader

        return super(StaticheaderElementCreateModal, self).form_valid(form, forms)


class StaticheaderElementUpdateModal(MultiForm, GenUpdateModal):
    model = StaticheaderElement
    form_class = StaticheaderElementForm
    forms = formsfull["StaticheaderElement"]

    def form_valid(self, form, forms):
        new_forms = []
        for f in forms:
            if type(f[0]) != self.form_class:
                name_form = str(type(forms[1][0])).split('.')[-1].replace("'", '').replace('>', '')
                field_image = "{}_image".format(name_form)
                if field_image in json.loads(self.request.body) and 'filename' in json.loads(self.request.body)[field_image]:
                    name_file = json.loads(self.request.body)[field_image]['filename']
                    self.request.name_file = name_file
                    f[0].instance.name_file = name_file
            new_forms.append(f)
            
        try:
            return super(StaticheaderElementUpdateModal, self).form_valid(form, new_forms)
        except ValidationError as e:
            errors = form._errors.setdefault("public", ErrorList())
            errors.append(e)
            return super(StaticheaderElementUpdateModal, self).form_invalid(form, [tform[0] for tform in forms], 1, 0)


class StaticheaderElementDelete(GenDelete):
    model = StaticheaderElement


"""
class StaticheaderElementDetailsModal(GenDetailModal):
    model = StaticheaderElement
    groups = StaticheaderElementForm.__groups_details__()
    exclude_fields = ['frontheader']

"""


# ###########################################
# StaticPage
class StaticPageList(GenList):
    model = StaticPage
    extra_context = {'menu': ['StaticPage', 'people'], 'bread': [_('StaticPage'), _('People')]}


class StaticPageCreate(MultiForm, GenCreate):
    model = StaticPage
    form_class = StaticPageForm
    forms = formsfull["StaticPage"]
    form_ngcontroller = "CDNXCMSFormSliderCtrl"


class StaticPageCreateModal(GenCreateModal, StaticPageCreate):
    pass


class StaticPageUpdate(MultiForm, GenUpdate):
    model = StaticPage
    form_class = StaticPageForm
    forms = formsfull["StaticPage"]


class StaticPageUpdateModal(GenUpdateModal, StaticPageUpdate):
    pass


class StaticPageDelete(GenDelete):
    model = StaticPage


# ###########################################
# StaticPageAuthor
class StaticPageAuthorList(GenList):
    model = StaticPageAuthor
    extra_context = {'menu': ['StaticPageAuthor', 'people'], 'bread': [_('StaticPageAuthor'), _('People')]}


class StaticPageAuthorCreate(GenCreate):
    model = StaticPageAuthor
    form_class = StaticPageAuthorForm
    hide_foreignkey_button = True


class StaticPageAuthorCreateModal(GenCreateModal, StaticPageAuthorCreate):
    pass


class StaticPageAuthorUpdate(GenUpdate):
    model = StaticPageAuthor
    form_class = StaticPageAuthorForm
    hide_foreignkey_button = True


class StaticPageAuthorUpdateModal(GenUpdateModal, StaticPageAuthorUpdate):
    pass


class StaticPageAuthorDelete(GenDelete):
    model = StaticPageAuthor


# ###########################################
# StaticPage
class TemplateStaticPageList(GenList):
    model = TemplateStaticPage
    extra_context = {'menu': ['StaticPage', 'people'], 'bread': [_('StaticPage'), _('People')]}


class TemplateStaticPageCreate(GenCreate):
    model = TemplateStaticPage
    form_class = TemplateStaticPageForm


class TemplateStaticPageCreateModal(GenCreateModal, TemplateStaticPageCreate):
    pass


class TemplateStaticPagePageUpdate(GenUpdate):
    model = TemplateStaticPage
    form_class = TemplateStaticPageForm


class TemplateStaticPageUpdateModal(GenUpdateModal, TemplateStaticPagePageUpdate):
    pass


class TemplateStaticPageDelete(GenDelete):
    model = TemplateStaticPage


class TemplateStaticPageForeign(GenForeignKey):
    model = TemplateStaticPage
    label = "{name}"

    @method_decorator(login_required)
    def get(self, request, *args, **kwargs):
        # Get serach string
        search = kwargs.get('search', None)

        # Build queryset
        qs = self.model.objects.all()
        if search != '*':
            qs = qs.filter(name__icontains=search)

        # Initialize answer
        answer = {}
        answer['rows'] = []
        answer['clear'] = []
        answer['readonly'] = []

        # None
        token = {}
        token['id'] = None
        token['label'] = '---------'
        for lang_code in settings.LANGUAGES_DATABASES:
            token['StaticPageForm{}_tiles'.format(lang_code.upper())] = '{}'
        answer['rows'].append(token)

        # Entries
        for row in qs:
            # Initialize token
            token = {}
            token['id'] = row.pk
            token['label'] = row.name
            # Build tiles
            tile_base = json.loads(row.tile)
            tiles = {}
            for key in tile_base:
                tiles[key] = {'value': '', 'type': tile_base[key], 'deleted': False}

            # Set all tiles
            for lang_code in settings.LANGUAGES_DATABASES:
                token['StaticPageTextForm{}_tiles:__JSON_DATA__'.format(lang_code.upper())] = json.dumps(tiles)
            answer['rows'].append(token)

        # Dump answer
        try:
            json_answer = json.dumps(answer)
        except TypeError:
            raise TypeError("The structure can not be encoded to JSON")
        # Return the new answer
        return HttpResponse(json_answer, content_type='application/json')



# -*- coding: utf-8 -*-
#
# django-codenerix-cms
#
# Copyright 2017 Centrologic Computational Logistic Center S.L.
#
# Project URL : http://www.codenerix.com
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
import json
from django import template

from django.utils.translation import ugettext as _
from django.utils.safestring import mark_safe

from codenerix_cms.models import VALID_TYPE_TEMPLATE

register = template.Library()


@register.simple_tag(takes_context=True)
def cdnx_tiler_type(context, json_tiler_type):
    response = {'code_error': 0}
    # Si existe
    # entry_dict=json.loads(args[0])
    # if exist 2 arguments, first argument is name and second it's tag

    try:
        tiler_type = json.loads(json_tiler_type)
        valid_types = True

        # Itero por los campos. Si encuentro algun campo que no tiene un tipo correcto, almaceno el error. (Solo te va a avisar una vez por error.)
        for tag in tiler_type:
            if valid_types and tiler_type[tag] not in VALID_TYPE_TEMPLATE:
                valid_types = False
                response['code_error'] = 4
                response['error_msg'] = _("Type %(tag)s  does not a allowed type. List of allowed are: %(valid)s") % {'tag': tiler_type[tag], 'valid': VALID_TYPE_TEMPLATE}
        # Actualizo el diccionario de tipos.
        if valid_types:
            if 'cdnx_tiler_types' in context:
                context['cdnx_tiler_types'].update(tiler_type)
            else:
                context['cdnx_tiler_types'] = tiler_type

            response['data'] = context['cdnx_tiler_types']
    except ValueError as e:
        response['code_error'] = 1
        response['error_msg'] = _(
            "cdnx_tiler_type has wrong format: %(error)s"
        ) % {'error': e}

    # En desarrollo
    return mark_safe(json.dumps(response))


@register.simple_tag(takes_context=True)
def cdnx_tiler(context, fieldkey):
    response = {'code_error': 0}
    # Compruebo que existe un contexto previo para consultar
    if 'cdnx_tiler_types' in context:
        kinds = context['cdnx_tiler_types']
        # Si el campo está declarado, lo introduzco en el response
        if fieldkey in kinds.keys():
            response['data'] = {fieldkey: kinds[fieldkey]}
        # Si el campo no está registrado en el contexto, aviso al usuario de cuales son los campos validos.
        else:
            response['code_error'] = 2
            response['error_msg'] = _("Field %(field)s has not been declared, I can see only: %(fields)s") % {'field': fieldkey, 'fields': ", ".join(kinds.keys())}

    else:
        response['code_error'] = 3
        response['error_msg'] = _("Any type has been declared.")

    return mark_safe(json.dumps(response))


# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2017-11-08 15:28
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_cms', '0005_auto_20170517_1046'),
    ]

    operations = [
        migrations.AlterField(
            model_name='staticpage',
            name='status',
            field=models.CharField(choices=[('D', 'Draft'), ('R', 'Public'), ('P', 'Pending')], default='D', max_length=150, verbose_name='Status'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-03-27 10:21
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_cms', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='slider',
            name='identifier',
            field=models.CharField(blank=True, max_length=200, null=True, unique=True, verbose_name='Identifier'),
        ),
        migrations.AlterField(
            model_name='staticheader',
            name='identifier',
            field=models.CharField(blank=True, max_length=200, null=True, unique=True, verbose_name='Identifier'),
        ),
    ]



# -*- coding: utf-8 -*-
#
# django-codenerix-cms
#
# Copyright 2017 Centrologic Computational Logistic Center S.L.
#
# Project URL : http://www.codenerix.com
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import re
import json
import unicodedata

from django.core.validators import MaxValueValidator, MinValueValidator
from django.db import models, IntegrityError
from django.utils.encoding import smart_text
from django.utils.translation import ugettext_lazy as _
from django.template import Context, Template
from django.conf import settings

from django.core.exceptions import ValidationError

from codenerix.models import CodenerixModel, GenInterface
from codenerix_extensions.files.models import GenImageFileNull
from codenerix_extensions.helpers import get_external_method, get_language_database

from codenerix.fields import MultiBlockWysiwygField


VALID_TYPE_TEMPLATE = ('image', 'string', 'video')

HTML_FORMAT = (
    ('a', 'A'),
    ('b', 'B'),
    ('c', 'C'),
)

HEADER_HTML_FORMAT = (
    ('a', 'A'),
    ('b', 'B'),
    ('c', 'C'),
)

CHOICE_DRAFT = 'D'
CHOICE_PENDING = 'P'
CHOICE_PUBLIC = 'R'

STATUS_CHOICES = (
    (CHOICE_DRAFT, _('Draft')),
    (CHOICE_PUBLIC, _('Public')),
    (CHOICE_PENDING, _('Pending')),
)

"""
@summary: Este modelo es un modelo genérico para gestionar slider.
@var image: Atributo obligatorio. Contiene la imagen que se va a mostrar.
@var title: Atributo obligatorio. Referencia a la cabezara que se mostrará en el slider (útil para seo).
@var active: Atributo obligatorio. Si el booleano se encuentra a verdadero, la imagen se mostrará en el slider.
        Nota: Hay una constante que indica el número máximo de imagenes activas al mismo tiempo, es recomendable usarlo.
@var button: Atributo opcional. En caso de haberlo, aquí se añade una redirección a otra url.
        Note: Teniendo en cuenta que se prevee una entrada en deprecater por parte de URLField, controlar que lo que entra
        en button es una url.

"""


def extract_regex_cdnxtiler():
    # REGEX: Head
    regex = "(?:{%\ *cdnx_tiler\ +"
    # REGEX: First argument
    regex += "\"((\ )*\w*(\ )*)\""
    # REGEX: Tail
    regex += "(\ )*%})"
    # REGEX: Compile
    return re.compile(regex)


def extract_regex_cdnxtype():
    # REGEX: Head
    regex = "(?:{%\ *cdnx_tiler_type\ +"
    # REGEX: All character until symbol %}
    regex += '''\' *\{ *'''
    # REGEX: Element with comma
    regex += '''( *(\"\w+\") *: *(\"\w+\") *,'''
    # REGEX: Element without comma
    regex += '''| *(\"\w+\") *: *(\"\w+\") *)*'''
    # REGEX: Close dictionary
    regex += ''' *\} *\''''
    # REGEX: Tail
    regex += "\ *%})"
    # REGEX: Compile
    return re.compile(regex)


class GenBaseText(CodenerixModel, GenImageFileNull):  # META: Abstract class
    title = models.CharField(_("Title"), max_length=200, blank=True, null=True)
    description = models.TextField(_("Description"), null=True, blank=True)
    button = models.CharField(_("Button"), max_length=200, blank=True, null=True)
    url = models.CharField(_("URL"), max_length=500, blank=False, null=False)
    
    class Meta(CodenerixModel.Meta):
        abstract = True

    def __str__(self):
        return u"{}".format(self.title)

    def __unicode__(self):
        return self.__str__()

    def __fields__(self, info):
        fields = []
        fields.append(('title', _('Title'), 100))
        fields.append(('button', _('Button'), 100))
        fields.append(('url', _('URL'), 100))
        return fields


class GenMainInfo(CodenerixModel):  # META: Abstract class
    identifier = models.CharField(_("Identifier"), max_length=200, blank=True, null=True, unique=True)
    public = models.BooleanField(_("Public"), default=False)

    class Meta(CodenerixModel.Meta):
        abstract = True

    def __str__(self):
        return u"{}".format(self.identifier)

    def __unicode__(self):
        return self.__str__()

    def __fields__(self, info):
        fields = []
        fields.append(('identifier', _('Identifier'), 100))
        fields.append(('public', _('Public'), 100))
        return fields


class GenElementInfo(CodenerixModel):  # META: Abstract class
    order = models.IntegerField(_("Order"), blank=False, null=False, unique=False)
    show_title = models.BooleanField(_("Show title"), default=False)
    public = models.BooleanField(_("Public"), default=False)

    class Meta(CodenerixModel.Meta):
        abstract = True

    def __str__(self):
        return u"{}".format(self.order)

    def __unicode__(self):
        return self.__str__()

    def __fields__(self, info):
        fields = []
        fields.append(('order', _('Order'), 100))
        fields.append(('show_title', _('Show title'), 100))
        fields.append(('public', _('Public'), 100))
        return fields


class Slider(GenMainInfo):
    default = models.BooleanField(_("Default"), default=False)

    def __str__(self):
        return u"{}".format(self.identifier)

    def __unicode__(self):
        return self.__str__()

    def __fields__(self, info):
        fields = super(Slider, self).__fields__(info)
        fields.append(('default', _('Default'), 100))
        return fields


class SliderElement(GenElementInfo):
    html_format = models.CharField(_("HtmlFormat"), max_length=2, blank=True, null=True, choices=HTML_FORMAT)
    new_price = models.CharField(_("New price"), max_length=200, blank=True, null=True)
    old_price = models.CharField(_("Old price"), max_length=200, blank=True, null=True)
    discount = models.CharField(_("Discount"), max_length=200, blank=True, null=True)
    slider = models.ForeignKey(Slider, related_name="sliderelements", verbose_name=_("Slider"), blank=False, null=False)

    def __fields__(self, info):
        fields = super(SliderElement, self).__fields__(info)

        fields.append(('html_format', _('Html format'), 100))
        fields.append(('new_price', _('New price'), 100))
        fields.append(('old_price', _('Old price'), 100))
        fields.append(('discount', _('Discount'), 100))

        return fields


class Staticheader(GenMainInfo):
    html_format = models.CharField(_("HtmlFormat"), max_length=2, blank=True, null=True, choices=HEADER_HTML_FORMAT)
    num_elements = models.IntegerField(_("Number of columns"), blank=False, null=False, validators=[MaxValueValidator(4), MinValueValidator(1)])
    default = models.BooleanField(_("By default"), default=False)

    def __str__(self):
        return u"{}".format(self.identifier)

    def __unicode__(self):
        return self.__str__()

    def __fields__(self, info):
        fields = super(Staticheader, self).__fields__(info)
        fields.append(('html_format', _('Identificador'), 100))
        fields.append(('num_elements', _('Number columns'), 100))
        fields.append(('default', _('By default'), 100))
        return fields

    def save(self, *args, **kwargs):
        if self.default:
            Staticheader.objects.exclude(pk=self.pk).update(default=False)
        return super(Staticheader, self).save(*args, **kwargs)


class StaticheaderElement(GenElementInfo):
    frontheader = models.ForeignKey(Staticheader, related_name="staticheaderelements", verbose_name=_("Static Header"), blank=False, null=False)

    def save(self, *args, **kwargs):
        if self.public:
            if StaticheaderElement.objects.filter(public=True, frontheader=self.frontheader).exclude(pk=self.pk).count() >= self.frontheader.num_elements:
                raise ValidationError(_('Too many elements marked as "public". Unpublish some'))
        return super(StaticheaderElement, self).save(*args, **kwargs)


def calculate_slug(title, slug_origin, Model, pk):
    if slug_origin:
        slug_origin = slug_origin.strip()
    if not slug_origin:
        name = title.strip().replace(' ', '-')
        pattern = re.compile('[\W-]+')
        slug = pattern.sub('', name).lower()
    else:
        slug = slug_origin.lower()
    slug = ''.join((c for c in unicodedata.normalize('NFD', smart_text(slug)) if unicodedata.category(c) != 'Mn'))
    while Model.objects.filter(slug=slug).exclude(pk=pk).exists():
        slug += '_'
    return slug


# ###################################
# Static Pages


class StaticPageText(CodenerixModel):  # META: Abstract class
    """
    @ivar tiles: Contiene un diccionario de diccionarios, donde la clave es el nombre del elemento, y el valor es otro diccionario con el tipo y valor asociado.
        p.e. {'nombre':{'type':'string', 'value';'Nombre dado', 'render':'vimeo'}, ...}
    """
    slug = models.CharField(_('slug'), max_length=200, blank=False, null=False, unique=True)
    tiles = MultiBlockWysiwygField(_('Tiles'), blank=True, null=False)

    class Meta(CodenerixModel.Meta):
        abstract = True

    def __str__(self):
        return u"{}".format(self.slug)

    def __unicode__(self):
        return self.__str__()

    def __fields__(self, info):
        fields = []
        fields.append(('slug', _('Slug'), 100))
        return fields

    def update(self, tiles=None, *args, **kwargs):
        if tiles:
            if self.tiles:
                actual_tiles = json.loads(self.tiles)
            else:
                actual_tiles = {}

            for t in tiles:

                if t not in actual_tiles:
                    actual_tiles[t] = {"type": tiles[t], "value": "", "deleted": False}
                else:
                    actual_tiles[t]["type"] = tiles[t]
            for at in actual_tiles:
                if at not in tiles:
                    actual_tiles[at]["deleted"] = True

            self.tiles = json.dumps(actual_tiles)
            self.save()

    def save(self, *args, **kwargs):
        if not self.tiles:
            self.tiles = '{}'
        return super(StaticPageText, self).save(*args, **kwargs)


class TemplateStaticPage(CodenerixModel):
    """
    @ivar template: Contiene un template html, las etiquetas de mensaje se encontrarán con este patrón {+ name:type +}, type debe coincidir con un tipo valido.
    """

    name = models.CharField(_('Name'), max_length=150, blank=False, null=False)
    template = models.TextField(_('Template'), blank=False, null=False)
    # template = BootstrapWysiwygField(_('Template'), blank=False, null=False)
    tile = models.TextField(_('Tile'), blank=False, null=False)

    def __str__(self):
        return u"{}".format(smart_text(self.name))

    def __unicode__(self):
        return self.__str__()

    def __fields__(self, info):
        fields = []
        fields.append(('name', _('Title'), 100))

        return fields

    def save(self, *args, **kwargs):
        # Vars
        p = extract_regex_cdnxtiler()
        pt = extract_regex_cdnxtype()
        res = []
        ctx_type = {'cdnx_tiler_types': {}}
        tiles = {}

        # Extraction of labels
        for item in re.finditer(pt, self.template):
            res_type = json.loads(Template("{{% load cdnxcms_tiler_validator %}}{}".format(item.group(0))).render(Context(ctx_type)))
            # I extract context
            if 'data' in res_type:
                ctx_type['cdnx_tiler_types'] = res_type['data']
            res.append(res_type)
        # Si hay algúna etiqueta tiler se extrae
        if p.search(self.template):
            # Si hay algun tipo declarado, simplemente no hago nada, de esto se encarga el formulario
            if ctx_type['cdnx_tiler_types']:
                for item in re.finditer(p, self.template):

                    dict_response = json.loads(Template(
                        "{{% load cdnxcms_tiler_validator %}}{}"
                        .format(
                            item.group(0)
                        )
                    ).render(
                        Context(ctx_type))
                    )

                    if dict_response['code_error'] == 0:
                        tiles.update(dict_response['data'])
                    # If exist an error, then i send a Validation Error with message
                    elif dict_response['code_error'] > 0:
                        raise IntegrityError(dict_response['error_msg'])

        self.tile = json.dumps(tiles)

        # Update static pages
        for sp in self.staticpages.all():

            sp.update(tiles)

        return super(TemplateStaticPage, self).save(*args, **kwargs)

    @staticmethod
    def check_template(template):
        p = extract_regex_cdnxtiler()
        pt = extract_regex_cdnxtype()
        res = []
        ctx_type = {'cdnx_tiler_types': {}}

        for item in re.finditer(pt, template):
            res_type = json.loads(Template(
                "{{% load cdnxcms_tiler_validator %}}{}".format(item.group(0))
            ).render(Context(ctx_type)))
            # I extract context
            if 'data' in res_type:
                ctx_type['cdnx_tiler_types'] = res_type['data']
            res.append(res_type)
        # Si hay algúna etiqueta tiler se extrae
        if p.search(template):
            # Si hay algun tipo declarado, mando el error al formulario
            if ctx_type['cdnx_tiler_types']:
                for item in re.finditer(p, template):
                    res.append(json.loads(Template(
                        "{{% load cdnxcms_tiler_validator %}}{}"
                        .format(item.group(0)))
                        .render(Context(ctx_type))))
            else:
                res.append({'code_error': 6, 'error_msg': _(
                    "Your cdnx_tiler_type is missing or bad formed.")
                })
        return res


class ABSTRACT_GenStaticPageAuthor(models.Model):

    class Meta(CodenerixModel.Meta):
        abstract = True


class StaticPageAuthor(CodenerixModel):
    class CodenerixMeta:
        abstract = ABSTRACT_GenStaticPageAuthor

    def __str__(self):
        if hasattr(self, 'external'):
            return u"{}".format(smart_text(self.external.CDNXCMS_get_summary()))
        else:
            return u"{}".format(smart_text(_('No data!')))

    def __unicode__(self):
        return self.__str__()

    def __fields__(self, info):
        fields = []
        external_fields = get_external_method(StaticPageAuthor, '__fields_staticpage__', info)
        for (external_path, label) in external_fields:
            fields.append(("external__{}".format(external_path), label), )
        
        return fields

    @staticmethod
    def foreignkey_external():
        bridge = get_external_method(StaticPageAuthor, GenStaticPageAuthor.CodenerixMeta.force_methods['foreignkey_author'][0])
        if bridge is None:
            raise IOError("No bridge found with StaticPageAuthor, you should use GenStaticPageAuthor on your model to link to this one! If you are not willing to use this feature, please include in your urls.py only the URLs you need for your purpose")
        return bridge


class StaticPage(CodenerixModel):
    author = models.ForeignKey(StaticPageAuthor, related_name="staticpages", blank=True, null=True)
    status = models.CharField(_('Status'), max_length=150, blank=False, null=False, choices=STATUS_CHOICES, default=CHOICE_DRAFT)
    template = models.ForeignKey(TemplateStaticPage, related_name="staticpages", blank=False, null=False)

    def __fields__(self, info):
        lang = get_language_database()
        fields = []
        fields.append(('{}__slug'.format(lang), _('Slug'), 100))
        fields.append(('get_status_display', _('Status'), 100))
        fields.append(('author', _('Author'), 100))
        return fields

    def __str__(self):
        return u"{} ({})".format(smart_text(self.template), self.status)

    def __unicode__(self):
        return self.__str__()

    def update(self, tiles=None, *args, **kwargs):
        # I make sure to have tiles.
        if not tiles:
            tiles = json.loads(self.template.tile)

        for lang_code in settings.LANGUAGES_DATABASES:
            getattr(self, lang_code.lower()).update(tiles)


# author
class GenStaticPageAuthor(GenInterface, ABSTRACT_GenStaticPageAuthor):  # META: Abstract class
    author = models.OneToOneField(StaticPageAuthor, related_name='external', verbose_name=_("Author"), null=True, on_delete=models.SET_NULL, blank=True)

    class Meta(GenInterface.Meta, ABSTRACT_GenStaticPageAuthor.Meta):
        abstract = True

    class CodenerixMeta:
        force_methods = {
            'foreignkey_author': ('CDNXCMS_get_fk_info_author', _('---')),
            'get_name_related': ('CDNXCMS_get_name_related', _('---')),
            'get_summary': ('CDNXCMS_get_summary', ),
        }

    def save(self, *args, **kwards):
        if hasattr(self, 'author') and self.author is None:
            author = StaticPageAuthor()
            author.save()
            self.author = author

        return super(GenStaticPageAuthor, self).save(*args, **kwards)


MODELS = [
    ("slider_element", "SliderElement", "GenBaseText"),
    ("staticheader_element", "StaticheaderElement", "GenBaseText"),
    ("static_page", "StaticPage", "StaticPageText"),
]

for info in MODELS:
    field = info[0]
    model = info[1]
    base_model = info[2]
    for lang_code in settings.LANGUAGES_DATABASES:
        query = "class {}Text{}({}):\n".format(model, lang_code, base_model)
        query += "    {} = models.OneToOneField({}, blank=False, null=False, related_name='{}')\n".format(field, model, lang_code.lower())
        if model == 'StaticPage':

            query += "    def save(self, *args, **kwargs): \n"
            query += "        self.slug = calculate_slug('', self.slug, StaticPageText{}, self.pk)\n".format(lang_code)
            query += "        return super(StaticPageText{}, self).save(*args, **kwargs)\n".format(lang_code)

        exec(query)
